﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using BexIDE.Themes;

namespace BexIDE.GUI {
    public class BexTabControl : TabControl {

        #region Fields

        private Theme _theme;

        #endregion Fields

        #region Properties

        /// <summary>
        /// Gets or sets the theme of the tab control.
        /// </summary>
        public Theme Theme {
            get { return _theme; }
            set { _theme = value; }
        }

        /// <summary>
        /// Gets the current tab as a BexTab.
        /// </summary>
        public BexTab CurrentTab {
            get { return SelectedTab as BexTab; }
        }

        #endregion Properties

        #region ctor()

        /// <summary>
        /// Creates a new BexIDE tab control with the default theme.
        /// </summary>
        public BexTabControl() : this(new DefaultTheme()) { }

        /// <summary>
        /// Creates a new BexIDE tab control with the specified theme.
        /// </summary>
        /// <param name="t">Them for the tab control.</param>
        public BexTabControl(Theme t) {
            Theme = t;

            DrawMode = TabDrawMode.OwnerDrawFixed;
            SizeMode = TabSizeMode.Fixed;
        }

        #endregion ctor()

        #region Methods

        /// <summary>
        /// Paints a transparent background, getting rid of default whitespace.
        /// </summary>
        /// <param name="graphics">Graphics to draw to.</param>
        /// <param name="clipRect">Rectangle to clear.</param>
        protected void PaintTransparentBackground(Graphics graphics, Rectangle clipRect)
        {
            graphics.Clear(Color.Transparent);
            if ((this.Parent != null))
            {
                clipRect.Offset(this.Location);
                PaintEventArgs e = new PaintEventArgs(graphics, clipRect);
                GraphicsState state = graphics.Save();
                graphics.SmoothingMode = SmoothingMode.HighSpeed;
                try
                {
                    graphics.TranslateTransform((float)-this.Location.X, (float)-this.Location.Y);
                    this.InvokePaintBackground(this.Parent, e);
                    this.InvokePaint(this.Parent, e);
                }
                finally
                {
                    graphics.Restore(state);
                    clipRect.Offset(-this.Location.X, -this.Location.Y);
                }
            }
        }

        /// <summary>
        /// Overridden tab item background painting.
        /// </summary>
        protected override void OnDrawItem(DrawItemEventArgs e) {
            Rectangle tabRect = GetTabRect(e.Index);
            RectangleF tabTextRect = (RectangleF)GetTabRect(e.Index);
            TabPage tab = TabPages[e.Index];

            tabTextRect.X += 12f;
            tabTextRect.Y += 6f;

            LinearGradientBrush b = new LinearGradientBrush(tabRect, Theme.MenuGradientPrimary, Theme.MenuGradientSecondary, 270f);
            e.Graphics.FillRectangle(b, tabRect);
            e.Graphics.DrawString(tab.Text, Font, new SolidBrush(Theme.TextColor), tabTextRect);
        }

        #endregion Methods

    }
}