﻿using System;
using System.Drawing;

namespace BexIDE.Themes {
    /// <summary>
    /// Provides methods and properties to support a theme for BexIDE.
    /// </summary>
    public class Theme {

        #region Fields

        // When I first wrote this I used the Visual Studio-allowed { get; set; }
        // for properties, but Mono does not allow this in-source, so instead
        // of creating a variable for each property, I just made an array.

        private Color[] colors;
        private string name;

        #endregion Fields

        #region Properties

        /// <summary>
        /// Gets or sets the name of the theme.
        /// </summary>
        public string Name {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        /// Gets or sets the forecolor of the theme.
        /// </summary>
        public Color ForeColor {
            get { return colors[0]; }
            set { colors[0] = value; }
        }

        /// <summary>
        /// Gets or sets the backcolor of the theme.
        /// </summary>
        public Color BackColor {
            get { return colors[1]; }
            set { colors[1] = value; }
        }

        /// <summary>
        /// Gets or set the dark color used for menu items.
        /// </summary>
        public Color SeperatorDark {
            get { return colors[2]; }
            set { colors[2] = value; }
        }

        /// <summary>
        /// Gets or sets the light color used for menu items.
        /// </summary>
        public Color SeparatorLight {
            get { return colors[3]; }
            set { colors[3] = value; }
        }

        /// <summary>
        /// Gets or sets the primary gradient for menus.
        /// </summary>
        public Color MenuGradientPrimary {
            get { return colors[4]; }
            set { colors[4] = value; }
        }

        /// <summary>
        /// Gets or sets the secondary gradient for menus.
        /// </summary>
        public Color MenuGradientSecondary {
            get { return colors[5]; }
            set { colors[5] = value; }
        }

        /// <summary>
        /// Gets or sets the color of the border of selected menu items.
        /// </summary>
        public Color MenuItemSelectedBorder {
            get { return colors[6]; }
            set { colors[6] = value; }
        }

        /// <summary>
        /// Gets or sets the filled color of selected menu items.
        /// </summary>
        public Color MenuItemSelectedFill {
            get { return colors[7]; }
            set { colors[7] = value; }
        }

        /// <summary>
        /// Gets or sets the color for drop-down collection borders.
        /// </summary>
        public Color DropdownBorder {
            get { return colors[8]; }
            set { colors[8] = value; }
        }

        /// <summary>
        /// Gets or sets the color to fill drop-down collections with.
        /// </summary>
        public Color DropdownFill {
            get { return colors[9]; }
            set { colors[9] = value; }
        }

        /// <summary>
        /// Gets or sets the text color of the theme.
        /// </summary>
        public Color TextColor {
            get { return colors[10]; }
            set { colors[10] = value; }
        }

        #endregion Properties

        #region ctor()

        /// <summary>
        /// Creates a new Theme.
        /// </summary>
        public Theme() {
            name = "<white>";
            colors = new Color[11];
            for (int i = 0; i < colors.Length; i++)
                colors[i] = Color.White;
        }

        #endregion

    }
}