﻿using System;
using System.Collections.Generic;
using System.IO;

namespace BexIDE.Tools
{
    public static class Logger
    {

        #region Fields

        private static StreamWriter _writer;
        private static bool _active;

        #endregion Fields

        #region ctor()

        static Logger()
        {
            _writer = null;
            _active = false;
        }

        #endregion ctor()

        #region Methods

        /// <summary>
        /// Begins the logger and places the file in the specified directory.
        /// </summary>
        /// <param name="dir"></param>
        public static void Begin(string dir)
        {
            _writer = GetLogStream(dir);
            _active = true;
        }

        /// <summary>
        /// Clears the logger and ends activity.
        /// </summary>
        public static void End()
        {
            if (_writer != null)
            {
                _writer.Flush();
                _writer.Close();
                _writer.Dispose();
                _writer = null;
                _active = false;
            }
        }

        /// <summary>
        /// Logs a message with a time stamp.
        /// </summary>
        /// <param name="msg">Message to log.</param>
        public static void LogMessage(string msg)
        {
            if (_active)
                LogSecret(GetTimeStamp() + msg, false);
        }

        /// <summary>
        /// Logs a message without a time stamp.
        /// </summary>
        /// <param name="msg">Message to log.</param>
        public static void LogSecret(string msg, bool prefix)
        {
            if (_active)
            {
                if (prefix)
                    _writer.Write("* ");
                _writer.WriteLine(msg);
            }
        }

        /// <summary>
        /// Gets the current time stamp.
        /// </summary>
        /// <returns>String representing the current time.</returns>
        private static string GetTimeStamp()
        {
            DateTime dt = DateTime.Now;
            return string.Format("[{0}:{1}:{2}] ", dt.Hour, dt.Minute, dt.Second);
        }

        /// <summary>
        /// Gets the stream for writing to the log file.
        /// </summary>
        /// <param name="dir">Directory to get or create the log file.</param>
        /// <returns>A StreamWriter for the log file.</returns>
        private static StreamWriter GetLogStream(string dir)
        {
            string logFile = dir + "log.txt";

            if (File.Exists(logFile))
                return new StreamWriter(File.Open(logFile, FileMode.Append));
            else
                return new StreamWriter(File.Create(logFile));
        }

        #endregion Methods

    }
}