﻿using System;
using System.Diagnostics;

// For reference: http://wabbit.codeplex.com/wikipage?title=Commandline%20Arguments&referringTitle=Documentation

namespace BexIDE.Tools {
    public enum WabbitMemState {
        RAM,
        Archive
    }

    public static class WabbitInterface {

		#region Fields

		private static string wabbitLoc;

		#endregion Fields

        #region Properties

        /// <summary>
        /// Gets or sets the location of WabbitEMU.
        /// </summary>
        public static string WabbitLocation {
			get { return wabbitLoc; }
			set { wabbitLoc = value; }
		}

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sends files to WabbitEMU with the specified options.
        /// </summary>
        /// <param name="state">Memory location to send files to.</param>
        /// <param name="focus">Decides whether or not to bring WabbitEMU to focus on sending files.</param>
        /// <param name="files">Files to send.</param>
        public static void SendFiles(WabbitMemState state, bool focus, params string[] files) {
            if (string.IsNullOrEmpty(WabbitLocation))
                throw new Exception("Cannot send files. Location of WabbitEMU must be set.");

            string args = "wabbitemu ";

            // Add memory location argument
            if (state == WabbitMemState.Archive)
                args += "-A ";
            else // if (state == WabbitMemState.RAM)
                args += "-R ";

            // Add focus arg if needed
            if (focus)
                args += "-F ";

            // Add files
            foreach (string file in files)
				args += string.Format("\"{0}\" ", file);

            Process.Start(WabbitLocation, args);
        }

        #endregion Methods

    }
}